@@ -2,6 +2,8 @@
 
 from hammurabi.config import config
 from hammurabi.law import Law
+from hammurabi.notifications.base import Notification
+from hammurabi.notifications.slack import SlackNotification
 from hammurabi.pillar import Pillar
 from hammurabi.preconditions.attributes import (
     HasMode,
@@ -55,4 +57,4 @@ from hammurabi.rules.yaml import (
     YAMLValueNotExists,
 )
 
-__version__ = "0.7.3"
+__version__ = "0.8.0"
